@@ -17,7 +17,6 @@ loocv.surrosurv <- function(object,
       'Poisson TI',
       'Poisson TIa'
     )
-    
     models <- allmodels[allmodels %in% names(object)]
   }
   loocv.data.frame(attr(object, 'data'), models = models, ...)
@@ -73,8 +72,7 @@ loocv.data.frame <- function(object,
           paste0(
             'The number of cores (nCores=',
             nCores,
-            ') is greater than',
-            'the number of ',
+            ') is greater than the number of ',
             ifelse(nTrials < totCores, 'trials', 'cores detected'),
             ' (',
             min(nTrials, totCores),
@@ -97,17 +95,16 @@ loocv.data.frame <- function(object,
     redobject$trialref <- factor(redobject$trialref)
     predint <- tryCatch(
       expr = {
-        surrofit <-
-          surrosurv(data = redobject, models = models2predict, ...)
-        res <-
-          lapply(attr(predict(surrofit), 'predf'), function(x)
-            x(alpha))
+        surrofit <- surrosurv(data = redobject, models = models2predict, ...)
+        res <- lapply(attr(predict(surrofit), 'predf'), function(x) x(alpha))
         names <- names(res)
         res <- lapply(1:length(res), function(i)
           rbind(res[[i]], t(print(
             surrofit, silent = TRUE
           ))[, i, drop = FALSE]))
         names(res) <- names
+        attr(res, 'convergence') <- convergence(surrofit)
+        attr(res, 'convals') <- convals(surrofit)
         res
       },
       error = function(e) {
@@ -116,7 +113,8 @@ loocv.data.frame <- function(object,
           if (length(coppos) == 1) {
             models2predict <- c(models2predict[1:coppos - 1],
                                 paste(cop, c('unadj', 'adj'), sep = '.'),
-                                as.character(na.omit(models2predict[(coppos + 1):(length(models2predict) + 1)])))
+                                as.character(na.omit(models2predict[
+                                  (coppos + 1):(length(models2predict) + 1)])))
           }
         }
         poipos <- which(models2predict == 'Poisson')
@@ -124,21 +122,23 @@ loocv.data.frame <- function(object,
           models2predict <- c(models2predict[0:(poipos - 1)],
                               paste0('Poisson', c('T', 'TI', 'TIa')))
         }
-        return(mapply(function(i)
-          return(t(t(
-            c(
-              fit = NA,
-              lwr = NA,
-              upr = NA,
-              kTau = NA,
-              R2 = NA
-            )
+        res <- mapply(function(i)
+          return(t(t(c(fit = NA,
+                       lwr = NA,
+                       upr = NA,
+                       kTau = NA,
+                       R2 = NA)
           ))),
-          models2predict, SIMPLIFY = FALSE))
+          models2predict, SIMPLIFY = FALSE)
+        attr(res, 'convergence') <- attr(res, 'convals') <- 
+          matrix(NA, length(models2predict), 3)
+        return(res)
       }
     )
     RES <- c(list(margPars = c(alpha = alpha, beta = beta)),
              predint)
+    attr(RES, 'convergence') <- attr(predint, 'convergence')
+    attr(RES, 'convals') <- attr(predint, 'convals')
     return(RES)
   }
   
@@ -150,8 +150,7 @@ loocv.data.frame <- function(object,
   }
   clusterEvalQ(cl, library('survival'))
   clusterEvalQ(cl, library('surrosurv'))
-  loocvRES <-
-    clusterApplyLB(cl, levels(object$trialref), loof, ...)
+  loocvRES <- clusterApplyLB(cl, levels(object$trialref), loof, ...)
   stopCluster(cl)
   rm(cl)
   
@@ -176,12 +175,14 @@ print.loocvSurrosurv <- function(x,
       } else {
         trial[[y]]
       }
-      c(obsBeta = trial$margPars['beta'], trialRes)
+      c(obsAlpha = trial$margPars['alpha'], 
+        obsBeta = trial$margPars['beta'], 
+        trialRes)
     })
     preds <- matrix(unlist(preds),
-                    nrow = 6,
+                    nrow = 7,
                     dimnames = list(
-                      c('obsBeta', 'predict', 'lwr', 'upr', 'kTau', 'R2'),
+                      c('obsAlpha', 'obsBeta', 'predict', 'lwr', 'upr', 'kTau', 'R2'),
                       names(x)
                     ))
     return(preds)
@@ -216,9 +217,12 @@ print.loocvSurrosurv <- function(x,
 ################################################################################
 plot.loocvSurrosurv <- function(x,
                                 models,
-                                exact.models, ...) {
+                                exact.models, 
+                                plot.type = c('classic', 'regression'),
+                                main, ylab, xlab, ...) {
   # ************************************************************************** #
   x <- print(x, silent = TRUE)
+  
   if (missing(models))
     models <- setdiff(names(x), 'margPars')
   
@@ -232,11 +236,13 @@ plot.loocvSurrosurv <- function(x,
     ind <- which(sapply(tolower(noSpP(names(
       x
     ))), function(mod)
-      ! all(is.na(
+      !all(is.na(
         pmatch(tolower(noSpP(models)), mod)
       ))))
   }
   
+  plot.type <- match.arg(plot.type)
+  
   mypalette <-
     c(
       orange = rgb(234, 104, 14, maxColorValue = 255, alpha = 180),
@@ -255,25 +261,43 @@ plot.loocvSurrosurv <- function(x,
   
   if (length(ind)) {
     par(mfrow = n2mfrow(length(ind)))
+    if (!missing(main)) {
+      if (length(main) == 1) mains <- rep(main, length(ind))
+      else mains <- main
+    } else mains <- format.methodNames(x)
+    
+    if (plot.type == 'classic') {
+      XLAB <- ifelse(missing(xlab), 'Trials', xlab)
+    } else {
+      XLAB <- ifelse(missing(xlab), 'Hazard ratio on the surrogate endpoint', xlab)
+    }
+    
     for (i in ind) {
+      if (plot.type == 'classic') {
+        xlims <- c(0, ncol(x[[i]])) + .5
+        Xs <- 1:ncol(x[[i]])
+      } else {
+        xlims <- range(x[[i]]['obsAlpha', ])
+        Xs <- x[[i]]['obsAlpha', ]
+      }
       plot(
         NA,
-        main = format.methodNames(x)[i],
-        xlim = c(0, ncol(x[[i]])) + .5,
-        xlab = 'Trials',
+        main = mains[i],
+        xlim = xlims,
+        xlab = XLAB,
         xaxt = 'n',
         ylim = range(x[[i]], na.rm = TRUE) +
           c(-1, 1) * diff(range(x[[i]], na.rm = TRUE)) / 20,
-        ylab = "Hazard ratio on the true endpoint",
+        ylab = ifelse(missing(ylab), 'Hazard ratio on the true endpoint', ylab),
         yaxt = 'n',
         panel.first = abline(h = 0, col = 'grey')
       )
-      axis(1, 1:ncol(x[[i]]), labels = colnames(x[[i]]))
-      axis(2, axTicks(2), format(round(exp(axTicks(
-        2
-      )), 2)), las = 1)
+      if (plot.type == 'classic') {
+        axis(1, 1:ncol(x[[i]]), labels = colnames(x[[i]]))
+      } else axis(1, axTicks(1), format(round(exp(axTicks(1)), 2)), las = 1)
+      axis(2, axTicks(2), format(round(exp(axTicks(2)), 2)), las = 1)
       segments(
-        1:ncol(x[[i]]),
+        Xs,
         x[[i]]['lwr',],
         y1 = x[[i]]['upr',],
         col = rgb(.6, .6, .6, .8),
@@ -282,7 +306,7 @@ plot.loocvSurrosurv <- function(x,
       # segments(1:ncol(x[[i]]) - .01, x[[i]]['predict', ], 1:ncol(x[[i]]) + .01,
       #          col = rgb(.2, .2, .2), lwd = 3, lend = 2)
       points(
-        1:ncol(x[[i]]),
+        Xs,
         x[[i]]['predict',],
         pch = 15,
         col = rgb(.2, .2, .2),
@@ -295,8 +319,8 @@ plot.loocvSurrosurv <- function(x,
                              order(x) == c(2, 1, 3))) == 3)
       NC <- is.na(x[[i]]['lwr',]) | is.na(x[[i]]['upr',])
       COLs[NC] <- 0
-      points(1:ncol(x[[i]]),
-             x[[i]][1,],
+      points(Xs,
+             x[[i]]['obsBeta',],
              pch = 16,
              cex = 1.4,
              col = COLs)
