@@ -36,9 +36,12 @@
 #   Date:                 June 22, 2015                                        #
 #   Last modification on: June 15, 2016                                        #
 #################################################################################
-poissonize <- function(data, 
-                       all.breaks = NULL, interval.width = NULL, nInts = 8,
-                       factors = NULL, compress = TRUE) {
+poissonize <- function(data,
+                       all.breaks = NULL,
+                       interval.width = NULL,
+                       nInts = 8,
+                       factors = NULL,
+                       compress = TRUE) {
   if (is.null(all.breaks)) {
     if (!is.null(interval.width)) {
       all.breaks <- seq(0, max(data$time),
@@ -47,66 +50,76 @@ poissonize <- function(data,
       # library('survival')
       smod <- survfit(Surv(time, status) ~ 1, data = data)
       smin <- min(smod$surv)
-      all.breaks <- c(0, sapply(1 - 1:nInts / nInts, function(p) 
+      all.breaks <- c(0, sapply(1 - 1:nInts / nInts, function(p)
         smod$time[(smod$surv - smin) / (1 - smin) <= p][1]))
     }
   }
   tol <- max(data$time) / 1e4
-  all.breaks <- sort(unique(setdiff(
-    round(c(0, all.breaks, max(data$time)) / tol), 
-    NA))) * tol
+  all.breaks <- sort(unique(setdiff(round(
+    c(0, all.breaks, max(data$time)) / tol
+  ),
+  NA))) * tol
   
   # THE FOLLOWING FUNCTION COMPUTES ALL THE TIME BREAKS GIVEN THE EXIT TIME
-  person.breaks <- Vectorize(function(stopT) unique(
-    c(all.breaks[all.breaks < stopT], stopT) / tol
-    ) * tol, SIMPLIFY = FALSE)
+  person.breaks <- Vectorize(function(stopT)
+    unique(c(all.breaks[all.breaks < stopT], stopT) / tol) * tol, SIMPLIFY = FALSE)
   
   # NEXT WE GET A LIST OF EACH SUBJECT'S TIME PERIODS
   the.breaks <- person.breaks(data$time)
   
   # NOW WE OBTAIN THE EXPANDED PERIOD OF OBSERVATION
-  startT <- lapply(the.breaks, function(x) x[-length(x)])  # LEFT TIME POINT
-  stopT <-  lapply(the.breaks, function(x) x[-1])    # RIGHT TIME POINTS
+  startT <-
+    lapply(the.breaks, function(x)
+      x[-length(x)])  # LEFT TIME POINT
+  stopT <-
+    lapply(the.breaks, function(x)
+      x[-1])    # RIGHT TIME POINTS
   
   # THE FOLLOWING ARE NEEDED TO COMPLETE THE LONG VERSION OF THE DATA SET
   count.per.id <- sapply(startT, length)
   index <- tapply(data$id, data$id, length)
-  index <- cumsum(index) # INDEX OF LAST OBSERVATION FOR EACH PATIENT
-  event <- rep(0,sum(count.per.id))
+  index <-
+    cumsum(index) # INDEX OF LAST OBSERVATION FOR EACH PATIENT
+  event <- rep(0, sum(count.per.id))
   event[cumsum(count.per.id)] <- data$status[index]
   
   # BRING ALL OF THIS TOGETHER TO CREATE THE EXPANDED DATASET
-  expData <- cbind(
-    data.frame(id = rep(data$id[index], count.per.id),
-               startT = unlist(startT),
-               stopT = unlist(stopT),
-               event = event),
-    data[sapply(rep(data$id[index], count.per.id), 
-                function(x) which(data$id==x)), factors, drop=FALSE])
+  expData <- cbind(data.frame(
+    id = rep(data$id[index], count.per.id),
+    startT = unlist(startT),
+    stopT = unlist(stopT),
+    event = event
+  ),
+  data[sapply(rep(data$id[index], count.per.id),
+              function(x)
+                which(data$id == x)), factors, drop = FALSE])
   
   
   
   # CREATE TIME VARIABLE WHICH INDICATES THE PERIOD OF OBSERVATION
   # THIS WILL BE THE OFFSET IN THE POISSON MODEL FIT
-  expData$time <- expData$stopT - expData$startT # LENGTH OF OBSERVATION
+  expData$time <-
+    expData$stopT - expData$startT # LENGTH OF OBSERVATION
   
   # NEXT WE CREATE A FACTOR FOR EACH INTERVAL THAT WILL ALLOW US
   # TO HAVE A DIFFERENT RATE FOR EACH PERIOD
-  expData$interval <- factor(expData$start, levels = unique(expData$start))
-  expData <- subset(expData, select=-c(startT, stopT))
+  expData$interval <-
+    factor(expData$start, levels = unique(expData$start))
+  expData <- subset(expData, select = -c(startT, stopT))
   #expData$time <- expData$time
   if (compress) {
     m <- aggregate(x = expData$event,
-                   by = expData[, c('interval', factors), drop=FALSE], 
+                   by = expData[, c('interval', factors), drop = FALSE],
                    sum)
     colnames(m)[ncol(m)] <- 'm'
     Rt <- aggregate(x = expData$time,
-                    by = expData[, c('interval', factors), drop=FALSE], 
+                    by = expData[, c('interval', factors), drop = FALSE],
                     sum)
     colnames(Rt)[ncol(Rt)] <- 'Rt'
     N <- aggregate(x = expData$event,
-                   by = expData[, c('interval', factors), drop=FALSE], 
-                   function(x) sum(!is.na(x)))
+                   by = expData[, c('interval', factors), drop = FALSE],
+                   function(x)
+                     sum(!is.na(x)))
     colnames(N)[ncol(N)] <- 'N'
     expData <- merge(m, merge(Rt, N, sort = FALSE), sort = FALSE)
   }
@@ -134,18 +147,22 @@ poissonize <- function(data,
 #   Date:                 June 22, 2015                                        #
 #   Last modification on: November 14, 2016                                    #
 ################################################################################
-plotsson <- function(x, 
+plotsson <- function(x,
                      type = c('survival', 'hazard'),
-                     add = FALSE, xscale = 1, by, col, ...) {
+                     add = FALSE,
+                     xscale = 1,
+                     by,
+                     col,
+                     ...) {
   type <- tolower(type)
   type <- match.arg(type)
   
   breaks <- attr(x$data, 'all.breaks')
-  risks <- exp(coef(x)[grep('interval', names(coef(x)))]) * 
+  risks <- exp(coef(x)[grep('interval', names(coef(x)))]) *
     diff(breaks)
   
   if (type == 'survival') {
-    risks <- exp(-cumsum(risks))    
+    risks <- exp(-cumsum(risks))
     Ylims <- 0:1
     Ylab <- 'Survival probability'
   } else {
@@ -157,28 +174,47 @@ plotsson <- function(x,
   stopT <- breaks[-1] / xscale
   
   if (!add)
-    plot(0, xlim = c(0, 1.1 * max(stopT)), ylim = Ylims,
-         xlab = 'time', ylab = Ylab, type = 'n', ...)
+    plot(
+      0,
+      xlim = c(0, 1.1 * max(stopT)),
+      ylim = Ylims,
+      xlab = 'time',
+      ylab = Ylab,
+      type = 'n',
+      ...
+    )
   
-  byVals <- if (missing(by)) {0} else {unique(x$data[, by])}
-  beta <- if (missing(by)) {0} else {coef(x)[by]}
+  byVals <- if (missing(by)) {
+    0
+  } else {
+    unique(x$data[, by])
+  }
+  beta <- if (missing(by)) {
+    0
+  } else {
+    coef(x)[by]
+  }
   
   if (type == 'survival') {
     for (v in 1:length(byVals))
-      segments(startT,
-               c(1, risks[2:length(risks) - 1]^exp(beta * byVals[v])),
-               stopT,
-               risks^exp(beta * byVals[v]), 
-               col = ifelse(missing(col), v, col),
-               ...)
+      segments(
+        startT,
+        c(1, risks[2:length(risks) - 1] ^ exp(beta * byVals[v])),
+        stopT,
+        risks ^ exp(beta * byVals[v]),
+        col = ifelse(missing(col), v, col),
+        ...
+      )
   } else {
-    for(v in 1:length(byVals))
-        segments(startT,
-                 risks * exp(beta * byVals[v]),
-                 stopT,
-                 risks * exp(beta * byVals[v]), 
-                 col = ifelse(missing(col), v, col), 
-                 ...)
+    for (v in 1:length(byVals))
+      segments(
+        startT,
+        risks * exp(beta * byVals[v]),
+        stopT,
+        risks * exp(beta * byVals[v]),
+        col = ifelse(missing(col), v, col),
+        ...
+      )
   }
   
 }
